import { app } from '../../app.ts';
import { ConfigModel } from './models/model.ts';

app
  .route({
    path: 'config',
    key: 'getUploadConfig',
    middleware: ['auth'],
  })
  .define(async (ctx) => {
    const tokenUser = ctx.state.tokenUser;
    const config = await ConfigModel.getUploadConfig({
      uid: tokenUser.id,
    });
    const key = config?.config?.data?.key || '';
    const version = config?.config?.data?.version || '';
    const username = tokenUser.username;
    const prefix = `${key}/${version}/`;
    ctx.body = {
      key,
      version,
      username,
      prefix,
    };
  })
  .addTo(app);

app
  .route({
    path: 'config',
    key: 'updateUploadConfig',
    middleware: ['auth'],
  })
  .define(async (ctx) => {
    const { id } = ctx.state.tokenUser;
    const data = ctx.query.data || {};
    const { key, version } = data;
    if (!key && !version) {
      ctx.throw(400, 'key or version is required');
    }
    const config = await ConfigModel.setUploadConfig({
      uid: id,
      data,
    });
    ctx.body = config;
  })
  .addTo(app);
